pub struct MaskingWriter<W: Write> { /* private fields */ }Expand description
A writer that buffers output and applies masking on flush / drop.
Created by MaskingMakeWriter. Buffers all write calls
and applies masking when the writer is flushed or dropped (at the end of each log event).